Django FileBrowser Documentation — Django FileBrowser 3.11.2 documentation

# Django FileBrowser Documentation

Media-Management with Grappelli.

Note

FileBrowser 3.11.2 requires Django 2.1 and Grappelli 2.12.

## Installation and Setup

- Quick start guide
  - Requirements
  - Installation
  - Settings
  - Testing
- Settings
  - Main URL/Paths Settings
  - Extensions and Formats
  - Versions
  - Placeholder
  - Extra Settings

## API

- API
  - FileListing
    - Methods
  - FileObject
    - Attributes
      - Initial Attributes
      - General Attributes
      - Path and URL attributes
      - Image attributes
      - Folder attributes
      - Version attributes
    - Methods
      - Version methods
      - Delete methods

## Fields & Widgets

- Fields & Widgets
  - FileBrowseField
  - Django FileField and the FileBrowser

## Admin Interface

- Admin Interface
  - FileBrowser Site
  - Custom Actions
  - File Storages
  - Views
  - Signals

## Image Versions

- Versions
  - Defining Versions
  - Custom processors
    - Using the processor
  - Versions and the Admin
  - Versions and the Frontend
    - Templatetag `version`
  - Versions in Views
  - Placeholder
  - Management Commands

## Help

- Help
  - FAQ
  - Troubleshooting
  - Translation
  - FileBrowser 3.11 Release Notes
- Testing
- Changelog

## Main Features

- Browse your media files with the admin interface.
- Multiple upload, including a progress bar.
- Automatic thumbnails.
- Image versions to fit your websites grid (esp. useful with adaptive/responsive layouts).
- Integration with TinyMCE.
- FileBrowseField to select images/documents.
- Signals for upload, rename and delete.
- Custom actions.
- Custom file storage engines.

## Code

https://github.com/sehmaschine/django-filebrowser

## Discussion

Use the FileBrowser Google Group to ask questions or discuss features.

## Versions and Compatibility

FileBrowser is always developed against the latest stable Django release and is NOT tested with Djangos trunk.

- FileBrowser 3.11.2 (November 14th, 2019): Compatible with Django 2.1
- FileBrowser 3.10.2 (November 2nd, 2018): Compatible with Django 2.0
- FileBrowser 3.9.2 (November 2nd, 2018): Compatible with Django 1.11

Current development branches:

- FileBrowser 3.11.3 (Development Version for Django = 2.1, see Branch Stable/3.11.x)
- FileBrowser 3.10.3 (Development Version for Django = 2.0, see Branch Stable/3.10.x)
- FileBrowser 3.9.3 (Development Version for Django = 1.11, see Branch Stable/3.9.x)

Older versions are available at GitHub, but are not supported anymore. Support for 3.10.x and 3.9.x is limited to security issues and very important bugfixes.